==> exactly-0.8.9.2.tar.gz: exactly-0.8.9.2/src/exactly_lib/util/description.py <==
from exactly_lib.util.textformat.structure.core import Text, StringText
from exactly_lib.util.textformat.structure.document import SectionContents


class Description(tuple):
    def __new__(cls,
                single_line_description: Text,
                rest_paragraphs: list):
        """
        :type single_line_description: Mandatory short description.
        :type rest_paragraphs: [ParagraphItem]
        """
        return tuple.__new__(cls, (single_line_description,
                                   rest_paragraphs))

    @property
    def single_line_description(self) -> Text:
        return self[0]

    @property
    def rest(self) -> list:
        """
        :rtype: [ParagraphItem]
        """
        return self[1]


class DescriptionWithSubSections(tuple):
    def __new__(cls,
                single_line_description: Text,
                rest: SectionContents):
        """
        :param single_line_description: Mandatory short description.
        """
        return tuple.__new__(cls, (single_line_description,
                                   rest))

    @property
    def single_line_description(self) -> Text:
        return self[0]

    @property
    def rest(self) -> SectionContents:
        return self[1]


def single_line_description(line: str) -> Description:
    return Description(StringText(line), [])


def single_line_description_with_sub_sections(line: str) -> DescriptionWithSubSections:
    return DescriptionWithSubSections(StringText(line),
                                      SectionContents([], []))


def from_simple_description(description: Description) -> DescriptionWithSubSections:
    return DescriptionWithSubSections(description.single_line_description,
                                      SectionContents(description.rest,
                                                      []))

==> exactly-0.9.1.1.tar.gz: exactly-0.9.1.1/src/exactly_lib/util/description.py <==
from typing import List

from exactly_lib.util.textformat.structure.core import Text, StringText, ParagraphItem
from exactly_lib.util.textformat.structure.document import SectionContents


class Description(tuple):
    def __new__(cls,
                single_line_description: Text,
                rest_paragraphs: List[ParagraphItem]):
        """
        :param single_line_description: Mandatory short description.
        """
        return tuple.__new__(cls, (single_line_description,
                                   rest_paragraphs))

    @property
    def single_line_description(self) -> Text:
        return self[0]

    @property
    def rest(self) -> List[ParagraphItem]:
        return self[1]


class DescriptionWithSubSections(tuple):
    def __new__(cls,
                single_line_description: Text,
                rest: SectionContents):
        """
        :param single_line_description: Mandatory short description.
        """
        return tuple.__new__(cls, (single_line_description,
                                   rest))

    @property
    def single_line_description(self) -> Text:
        return self[0]

    @property
    def rest(self) -> SectionContents:
        return self[1]


def single_line_description(line: str) -> Description:
    return Description(StringText(line), [])


def single_line_description_with_sub_sections(line: str) -> DescriptionWithSubSections:
    return DescriptionWithSubSections(StringText(line),
                                      SectionContents([], []))


def from_simple_description(description: Description) -> DescriptionWithSubSections:
    return DescriptionWithSubSections(description.single_line_description,
                                      SectionContents(description.rest,
                                                      []))
